@@ -28,6 +28,10 @@
 #define BLAS_INT const int
 
 #ifdef __cplusplus
+#   ifdef RcppArmadillo__RcppArmadilloForward__h
+#       error "BLAS.h must be included before RcppArmadillo.h!"
+#   endif
+#   define ARMA_DONT_USE_FORTRAN_HIDDEN_ARGS  // Don't use hidden args in calls to BLAS/LAPACK
 #   include <RcppArmadillo.h>
 #   include <R_ext/RS.h>
 #   define F77_R_NAME(x) F77_CALL(x)
